@@ -1,7 +1,9 @@
 package MooseX::Constructor::AllErrors;
 {
-  $MooseX::Constructor::AllErrors::VERSION = '0.020';
+  $MooseX::Constructor::AllErrors::VERSION = '0.021';
 }
+# git description: v0.020-19-ga0277cf
+
 
 use Moose ();
 use Moose::Exporter;
@@ -10,6 +12,7 @@ use MooseX::Constructor::AllErrors::Error;
 use MooseX::Constructor::AllErrors::Error::Constructor;
 use MooseX::Constructor::AllErrors::Error::Required;
 use MooseX::Constructor::AllErrors::Error::TypeConstraint;
+use MooseX::Constructor::AllErrors::Error::Misc;
 
 Moose::Exporter->setup_import_methods(
     base_class_roles => [ 'MooseX::Constructor::AllErrors::Role::Object' ],
